"""Checkbox detection analyzers for natural-pdf."""

from .checkbox_manager import CheckboxManager
from .checkbox_options import CheckboxOptions, RTDETRCheckboxOptions

__all__ = ["CheckboxManager", "CheckboxOptions", "RTDETRCheckboxOptions"]
